# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: algservice/services/grpc/alg-service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*algservice/services/grpc/alg-service.proto\x12\x0cservice.grpc\x1a\x1bgoogle/protobuf/empty.proto\"\"\n\x0fServiceVersion_\x12\x0f\n\x07version\x18\x01 \x01(\t\"&\n\x05Size_\x12\r\n\x05width\x18\x01 \x01(\x02\x12\x0e\n\x06height\x18\x02 \x01(\x02\"\x1e\n\x06Point_\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\"A\n\x05Rect_\x12\x0c\n\x04left\x18\x01 \x01(\x02\x12\x0b\n\x03top\x18\x02 \x01(\x02\x12\r\n\x05width\x18\x03 \x01(\x02\x12\x0e\n\x06height\x18\x04 \x01(\x02\"0\n\x08Polygon_\x12$\n\x06points\x18\x01 \x03(\x0b\x32\x14.service.grpc.Point_\"_\n\x06Shape_\x12)\n\x07polygon\x18\x02 \x01(\x0b\x32\x16.service.grpc.Polygon_H\x00\x12\"\n\x03\x62ox\x18\x03 \x01(\x0b\x32\x13.service.grpc.Rect_H\x00\x42\x06\n\x04\x64\x61ta\"@\n\x0b\x41lgRequest_\x12\r\n\x05\x61lgId\x18\x01 \x01(\t\x12\x11\n\talgParams\x18\x02 \x01(\t\x12\x0f\n\x07\x61lgData\x18\x03 \x01(\x0c\"k\n\x08Mission_\x12\x11\n\tmissionID\x18\x01 \x01(\t\x12#\n\x05shape\x18\x02 \x01(\x0b\x32\x14.service.grpc.Shape_\x12\'\n\x04\x61lgs\x18\x03 \x03(\x0b\x32\x19.service.grpc.AlgRequest_\"I\n\x0c\x41lgResponse_\x12\r\n\x05\x61lgId\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\x05\x12\x0c\n\x04resp\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\"t\n\x10MissionResponse_\x12\x11\n\tmissionId\x18\x01 \x01(\t\x12#\n\x05shape\x18\x04 \x01(\x0b\x32\x14.service.grpc.Shape_\x12(\n\x04\x61lgs\x18\x05 \x03(\x0b\x32\x1a.service.grpc.AlgResponse_\"\"\n\x12\x41lgorithmsRequest_\x12\x0c\n\x04name\x18\x01 \x01(\t\"z\n\x0e\x41lgorithmProp_\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tfieldType\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x65\x66\x61ultValue\x18\x03 \x01(\t\x12\x10\n\x08required\x18\x05 \x01(\x08\x12\r\n\x05label\x18\x06 \x01(\t\x12\x10\n\x08\x65xtValue\x18\x07 \x01(\t\"]\n\x0e\x41lgorithmInfo_\x12\r\n\x05\x61lgId\x18\x01 \x01(\t\x12\x0f\n\x07\x61lgName\x18\x02 \x01(\t\x12+\n\x05props\x18\x03 \x03(\x0b\x32\x1c.service.grpc.AlgorithmProp_\"O\n\x13\x41lgorithmsResponse_\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04\x61lgs\x18\x02 \x03(\x0b\x32\x1c.service.grpc.AlgorithmInfo_\"\xba\x01\n\x0e\x44\x65tectRequest_\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\x0c\x12(\n\x08missions\x18\x03 \x03(\x0b\x32\x16.service.grpc.Mission_\x12\x34\n\x04\x65xts\x18\x04 \x03(\x0b\x32&.service.grpc.DetectRequest_.ExtsEntry\x1a+\n\tExtsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd6\x01\n\x0f\x44\x65tectResponse_\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x30\n\x08missions\x18\x04 \x03(\x0b\x32\x1e.service.grpc.MissionResponse_\x12\x35\n\x04\x65xts\x18\x05 \x03(\x0b\x32\'.service.grpc.DetectResponse_.ExtsEntry\x1a+\n\tExtsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"R\n\x0fPreprocessData_\x12\r\n\x05\x61lgId\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0f\n\x07\x61lgData\x18\x04 \x01(\x0c\"\\\n\x1aMissionPreprocessResponse_\x12\x11\n\tmissionId\x18\x01 \x01(\t\x12+\n\x04\x61lgs\x18\x02 \x03(\x0b\x32\x1d.service.grpc.PreprocessData_\"\xe8\x01\n\x13PreprocessResponse_\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\x12:\n\x08missions\x18\x04 \x03(\x0b\x32(.service.grpc.MissionPreprocessResponse_\x12\x39\n\x04\x65xts\x18\x05 \x03(\x0b\x32+.service.grpc.PreprocessResponse_.ExtsEntry\x1a+\n\tExtsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\xc5\x02\n\nAlgService\x12\x45\n\nGetVersion\x12\x16.google.protobuf.Empty\x1a\x1d.service.grpc.ServiceVersion_\"\x00\x12V\n\rGetAlgorithms\x12 .service.grpc.AlgorithmsRequest_\x1a!.service.grpc.AlgorithmsResponse_\"\x00\x12O\n\nPreprocess\x12\x1c.service.grpc.DetectRequest_\x1a!.service.grpc.PreprocessResponse_\"\x00\x12G\n\x06\x44\x65tect\x12\x1c.service.grpc.DetectRequest_\x1a\x1d.service.grpc.DetectResponse_\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'algservice.services.grpc.alg_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DETECTREQUEST__EXTSENTRY']._loaded_options = None
  _globals['_DETECTREQUEST__EXTSENTRY']._serialized_options = b'8\001'
  _globals['_DETECTRESPONSE__EXTSENTRY']._loaded_options = None
  _globals['_DETECTRESPONSE__EXTSENTRY']._serialized_options = b'8\001'
  _globals['_PREPROCESSRESPONSE__EXTSENTRY']._loaded_options = None
  _globals['_PREPROCESSRESPONSE__EXTSENTRY']._serialized_options = b'8\001'
  _globals['_SERVICEVERSION_']._serialized_start=89
  _globals['_SERVICEVERSION_']._serialized_end=123
  _globals['_SIZE_']._serialized_start=125
  _globals['_SIZE_']._serialized_end=163
  _globals['_POINT_']._serialized_start=165
  _globals['_POINT_']._serialized_end=195
  _globals['_RECT_']._serialized_start=197
  _globals['_RECT_']._serialized_end=262
  _globals['_POLYGON_']._serialized_start=264
  _globals['_POLYGON_']._serialized_end=312
  _globals['_SHAPE_']._serialized_start=314
  _globals['_SHAPE_']._serialized_end=409
  _globals['_ALGREQUEST_']._serialized_start=411
  _globals['_ALGREQUEST_']._serialized_end=475
  _globals['_MISSION_']._serialized_start=477
  _globals['_MISSION_']._serialized_end=584
  _globals['_ALGRESPONSE_']._serialized_start=586
  _globals['_ALGRESPONSE_']._serialized_end=659
  _globals['_MISSIONRESPONSE_']._serialized_start=661
  _globals['_MISSIONRESPONSE_']._serialized_end=777
  _globals['_ALGORITHMSREQUEST_']._serialized_start=779
  _globals['_ALGORITHMSREQUEST_']._serialized_end=813
  _globals['_ALGORITHMPROP_']._serialized_start=815
  _globals['_ALGORITHMPROP_']._serialized_end=937
  _globals['_ALGORITHMINFO_']._serialized_start=939
  _globals['_ALGORITHMINFO_']._serialized_end=1032
  _globals['_ALGORITHMSRESPONSE_']._serialized_start=1034
  _globals['_ALGORITHMSRESPONSE_']._serialized_end=1113
  _globals['_DETECTREQUEST_']._serialized_start=1116
  _globals['_DETECTREQUEST_']._serialized_end=1302
  _globals['_DETECTREQUEST__EXTSENTRY']._serialized_start=1259
  _globals['_DETECTREQUEST__EXTSENTRY']._serialized_end=1302
  _globals['_DETECTRESPONSE_']._serialized_start=1305
  _globals['_DETECTRESPONSE_']._serialized_end=1519
  _globals['_DETECTRESPONSE__EXTSENTRY']._serialized_start=1259
  _globals['_DETECTRESPONSE__EXTSENTRY']._serialized_end=1302
  _globals['_PREPROCESSDATA_']._serialized_start=1521
  _globals['_PREPROCESSDATA_']._serialized_end=1603
  _globals['_MISSIONPREPROCESSRESPONSE_']._serialized_start=1605
  _globals['_MISSIONPREPROCESSRESPONSE_']._serialized_end=1697
  _globals['_PREPROCESSRESPONSE_']._serialized_start=1700
  _globals['_PREPROCESSRESPONSE_']._serialized_end=1932
  _globals['_PREPROCESSRESPONSE__EXTSENTRY']._serialized_start=1259
  _globals['_PREPROCESSRESPONSE__EXTSENTRY']._serialized_end=1302
  _globals['_ALGSERVICE']._serialized_start=1935
  _globals['_ALGSERVICE']._serialized_end=2260
# @@protoc_insertion_point(module_scope)
